@@ -217,6 +217,7 @@ __all__ = (
     "ListInventoryEntriesResultTypeDef",
     "ResourceComplianceSummaryItemTypeDef",
     "ListResourceComplianceSummariesResultTypeDef",
+    "ResourceDataSyncDestinationDataSharingTypeDef",
     "ResourceDataSyncS3DestinationTypeDef",
     "ResourceDataSyncOrganizationalUnitTypeDef",
     "ResourceDataSyncAwsOrganizationsSourceTypeDef",
@@ -2417,13 +2418,23 @@ ListResourceComplianceSummariesResultTypeDef = TypedDict(
     total=False,
 )
 
+ResourceDataSyncDestinationDataSharingTypeDef = TypedDict(
+    "ResourceDataSyncDestinationDataSharingTypeDef",
+    {"DestinationDataSharingType": str},
+    total=False,
+)
+
 _RequiredResourceDataSyncS3DestinationTypeDef = TypedDict(
     "_RequiredResourceDataSyncS3DestinationTypeDef",
     {"BucketName": str, "SyncFormat": Literal["JsonSerDe"], "Region": str},
 )
 _OptionalResourceDataSyncS3DestinationTypeDef = TypedDict(
     "_OptionalResourceDataSyncS3DestinationTypeDef",
-    {"Prefix": str, "AWSKMSKeyARN": str},
+    {
+        "Prefix": str,
+        "AWSKMSKeyARN": str,
+        "DestinationDataSharing": ResourceDataSyncDestinationDataSharingTypeDef,
+    },
     total=False,
 )
 
